Skip to contents

ledgr_pulse_features() returns the long feature rows available at one pulse. With a feature map, the result is filtered and ordered to the map and includes aliases. Without a map, all rows are returned with alias = NA.

Usage

ledgr_pulse_features(pulse, feature_map = NULL)

Arguments

pulse

A ledgr_pulse_context.

feature_map

Optional ledgr_feature_map. Filters and orders feature columns; does not rename them to aliases.

Value

A tibble with columns ts_utc, instrument_id, feature_id, feature_value, and alias.

Articles

Indicators, feature IDs, and pulse feature views:

vignette("indicators", package = "ledgr") system.file("doc", "indicators.html", package = "ledgr")

Examples

ledgr_pulse_features(pulse, features)
#> # A tibble: 1 × 5
#>   ts_utc              instrument_id feature_id feature_value alias
#>   <dttm>              <chr>         <chr>              <dbl> <chr>
#> 1 2020-01-03 00:00:00 AAA           sma_2               102. sma