Discovers stored runs in a DuckDB experiment-store file without recomputing or mutating runs. Archived runs are hidden by default.
Value
A ledgr_run_list object, which is a classed tibble with run
identity, including feature_set_hash, provenance, status, telemetry
summary, and basic result summary columns. Eleven appended completion
columns distinguish requested and achieved windows, completion status,
prefix-only performance, and affected instruments. Typed missing values
mean that completion evidence is unavailable, as for dense or historical
runs. See ledgr_identity_fields for hash-field semantics.
Examples
bars <- subset(ledgr_demo_bars, instrument_id == "DEMO_01")
snapshot <- ledgr_snapshot_from_df(utils::head(bars, 10))
strategy <- function(ctx, params) ctx$flat()
exp <- ledgr_experiment(snapshot, strategy, cost_model = ledgr_cost_zero(), opening = ledgr_opening(cash = 1000))
bt <- ledgr_run(exp, params = list(), run_id = "flat")
ledgr_run_list(snapshot)
#> # ledgr run list
#> # A tibble: 1 × 10
#> run_id label tags status final_equity total_return complete_performance
#> <chr> <chr> <lgl> <chr> <dbl> <chr> <lgl>
#> 1 flat NA NA DONE 1000 +0.0% NA
#> achieved_end_utc execution_mode reproducibility_level
#> <dttm> <chr> <chr>
#> 1 NA audit_log tier_1
#>
#> # i INCOMPLETE metrics describe the achieved prefix only.
#> # i Full identity and telemetry columns remain available on this tibble.
#> # i Inspect one run with ledgr_run_info(snapshot, run_id).
close(bt)
ledgr_snapshot_close(snapshot)