Print a run comparison
Usage
# S3 method for class 'ledgr_comparison'
print(x, ...)Arguments
- x
A
ledgr_comparisonobject returned byledgr_run_compare().- ...
Passed to the tibble print method for the curated view.
Print a run comparison
# S3 method for class 'ledgr_comparison'
print(x, ...)A ledgr_comparison object returned by ledgr_run_compare().
Passed to the tibble print method for the curated view.