Skip to contents

Prints a display copy of a ledgr result table. When options(ledgr.print_ts_utc = "auto"), all-midnight UTC timestamp columns are displayed as dates to keep EOD output compact. The underlying ts_utc column remains POSIXct UTC. Use options(ledgr.print_ts_utc = "datetime") to always display full datetimes.

Usage

# S3 method for class 'ledgr_result_table'
print(x, ...)

Arguments

x

A ledgr result table returned by ledgr_results().

...

Passed to the tibble print method.

Value

The input object, invisibly.