Print a run list
Usage
# S3 method for class 'ledgr_run_list'
print(x, ...)Arguments
- x
A
ledgr_run_listobject returned byledgr_run_list().- ...
Passed to the tibble print method for the curated view.
Print a run list
# S3 method for class 'ledgr_run_list'
print(x, ...)A ledgr_run_list object returned by ledgr_run_list().
Passed to the tibble print method for the curated view.