ledgr_pulse_features() returns the long feature rows available at one
pulse. With a feature map, the result is filtered and ordered to the map and
includes aliases. Without a map, all rows are returned with alias = NA.
Articles
Indicators, feature IDs, and pulse feature views:
vignette("indicators", package = "ledgr")
system.file("doc", "indicators.html", package = "ledgr")